@@ -19,7 +19,7 @@ use Types::Standard qw( Value Object Ref );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.4.4';
+our $VERSION = 'v0.4.5';
 
 
 sub import {
@@ -120,7 +120,7 @@ MooX::Const - Syntactic sugar for constant and write-once Moo attributes
 
 =head1 VERSION
 
-version v0.4.4
+version v0.4.5
 
 =head1 SYNOPSIS
 
@@ -201,6 +201,11 @@ test suite.
 
 It does not work with L<Mouse>. Pull requests are welcome.
 
+=head2 Write-Once Attributes
+
+L<Class::Accessor> antlers/moose-like mode uses "wo" for write-only
+attributes, not write-once attributes.
+
 =head1 SEE ALSO
 
 L<Const::Fast>
